from openskill.rate import (
    Rating,
    create_rating,
    ordinal,
    predict_draw,
    predict_win,
    rate,
    team_rating,
)

__version__ = "3.0.0"
